var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { EC2ServiceException } from '@aws-sdk/client-ec2';
import { AwsAccessDeniedError, AwsDependencyViolationError, AwsError, } from '../common/aws-errors.js';
export function ec2ErrorHandler(operation) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            return yield operation();
        }
        catch (error) {
            if (error instanceof EC2ServiceException &&
                error.name === 'UnauthorizedOperation') {
                throw new AwsAccessDeniedError();
            }
            if (error instanceof EC2ServiceException &&
                error.message.toLocaleLowerCase().includes('instance profile')) {
                throw new AwsInstanceProfileNotFoundError();
            }
            if (error instanceof EC2ServiceException &&
                error.message.toLowerCase().includes('volume attached')) {
                throw new AwsNoRootVolumeAttachedError();
            }
            if (error instanceof EC2ServiceException &&
                error.name === 'DependencyViolation') {
                throw new AwsDependencyViolationError();
            }
            throw error;
        }
    });
}
export class AwsInstanceProfileNotFoundError extends AwsError {
    constructor() {
        super('Instance profile not found');
    }
}
export class AwsNoRootVolumeAttachedError extends AwsError {
    constructor() {
        super('No root volume attached to the EC2 instance');
    }
}
//# sourceMappingURL=ec2-errors.js.map