var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DescribeInstancesCommand } from '@aws-sdk/client-ec2';
import { getTagFilter } from '../tags/get-tag-filter.js';
import { ec2Client } from './ec2-client.js';
import { parseEc2InstanceResponse } from './parse-ec2-response.js';
export function getEc2Instances({ vpcId, states, tags, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const filters = [
            ...(vpcId !== undefined ? [getVpcIdFilter(vpcId)] : []),
            ...(states !== undefined ? [getStateFilter(states)] : []),
            ...(tags !== undefined ? tags.map(tag => getTagFilter(tag)) : []),
        ];
        const { Reservations } = yield ec2Client.send(new DescribeInstancesCommand({
            Filters: filters.length > 0 ? filters : undefined,
        }));
        if (!Reservations) {
            throw new Error(`Invalid response from AWS.`);
        }
        return Reservations.flatMap(reservation => { var _a; return (_a = reservation.Instances) !== null && _a !== void 0 ? _a : []; }).map(instance => parseEc2InstanceResponse(instance));
    });
}
function getVpcIdFilter(vpcId) {
    return { Name: 'vpc-id', Values: [vpcId] };
}
function getStateFilter(states) {
    return { Name: 'instance-state-name', Values: states };
}
//# sourceMappingURL=get-ec2-instances.js.map