var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { ElastiCacheServiceException } from '@aws-sdk/client-elasticache';
import { AwsAccessDeniedError, AwsNotFoundError, AwsTooManySecurityGroupsAttachedError, } from '../common/aws-errors.js';
export function elasticacheErrorHandler(operation) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            return yield operation();
        }
        catch (error) {
            if (error instanceof ElastiCacheServiceException &&
                error.name === 'AccessDenied') {
                throw new AwsAccessDeniedError();
            }
            if (error instanceof ElastiCacheServiceException &&
                (error.name === 'CacheClusterNotFoundFault' ||
                    error.name === 'ReplicationGroupNotFoundFault' ||
                    error.name === 'CacheSubnetGroupNotFoundFault')) {
                throw new AwsNotFoundError();
            }
            if (error instanceof ElastiCacheServiceException &&
                error.name === 'InvalidParameterCombination' &&
                error.message.toLowerCase().includes('securitygroup')) {
                throw new AwsTooManySecurityGroupsAttachedError();
            }
            throw error;
        }
    });
}
//# sourceMappingURL=elasticache-errors.js.map