var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DescribeCacheClustersCommand } from '@aws-sdk/client-elasticache';
import { AwsNotFoundError } from '../common/aws-errors.js';
import { parseCacheNodeResponse } from './parse-elasticache-redis-response.js';
import { elasticacheClient } from './elasticache-client.js';
export function getCacheClusters() {
    return __awaiter(this, void 0, void 0, function* () {
        const { CacheClusters } = yield elasticacheClient.send(new DescribeCacheClustersCommand({ ShowCacheNodeInfo: true }));
        if (!CacheClusters) {
            throw new Error(`Invalid response from AWS.`);
        }
        const unFlatedArray = CacheClusters.map(nodeGroup => {
            if (nodeGroup.CacheNodes === undefined)
                return [];
            return nodeGroup.CacheNodes.map(cacheNode => {
                cacheNode.CacheNodeId = nodeGroup.CacheClusterId;
                return parseCacheNodeResponse(cacheNode, nodeGroup.ReplicationGroupId);
            });
        });
        return [...unFlatedArray.flat()];
    });
}
export function getRawCacheClusters() {
    return __awaiter(this, void 0, void 0, function* () {
        const { CacheClusters } = yield elasticacheClient.send(new DescribeCacheClustersCommand({}));
        if (!CacheClusters) {
            throw new Error(`Invalid response from AWS.`);
        }
        return CacheClusters;
    });
}
export function getDescribedCacheCluster(clusterIdentifier) {
    return __awaiter(this, void 0, void 0, function* () {
        const clusters = yield elasticacheClient.send(new DescribeCacheClustersCommand({
            CacheClusterId: clusterIdentifier,
            ShowCacheNodeInfo: true,
        }));
        if (clusters === undefined ||
            clusters.CacheClusters === undefined ||
            clusters.CacheClusters.length === 0 ||
            clusters.CacheClusters[0] === undefined) {
            throw new Error(`Cluster ${clusterIdentifier} not found`);
        }
        return clusters.CacheClusters[0];
    });
}
export function getCacheCluster({ identifier, }) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const cacheCluster = yield getDescribedCacheCluster(identifier);
            if (cacheCluster.ReplicationGroupId === undefined ||
                cacheCluster.CacheNodes === undefined ||
                cacheCluster.CacheNodes[0] === undefined) {
                throw new Error(`Invalid response from AWS.`);
            }
            return parseCacheNodeResponse(cacheCluster.CacheNodes[0], cacheCluster.ReplicationGroupId);
        }
        catch (error) {
            if (error instanceof AwsNotFoundError) {
                return undefined;
            }
            throw error;
        }
    });
}
//# sourceMappingURL=get-elasticache-cache-clusters.js.map