var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DescribeReplicationGroupsCommand } from '@aws-sdk/client-elasticache';
import { AwsNotFoundError } from '../common/aws-errors.js';
import { parseElasticacheResponse } from './parse-elasticache-redis-response.js';
import { elasticacheClient } from './elasticache-client.js';
export function getReplicationGroups() {
    return __awaiter(this, void 0, void 0, function* () {
        const { ReplicationGroups } = yield elasticacheClient.send(new DescribeReplicationGroupsCommand({}));
        if (!ReplicationGroups) {
            throw new Error(`Invalid response from AWS.`);
        }
        return ReplicationGroups.map(cluster => parseElasticacheResponse(cluster));
    });
}
export function getRawReplicationGroups() {
    return __awaiter(this, void 0, void 0, function* () {
        const { ReplicationGroups } = yield elasticacheClient.send(new DescribeReplicationGroupsCommand({}));
        if (!ReplicationGroups) {
            throw new Error(`Invalid response from AWS.`);
        }
        return ReplicationGroups;
    });
}
export function getReplicationGroupsByClusterMode() {
    return __awaiter(this, void 0, void 0, function* () {
        const { ReplicationGroups } = yield elasticacheClient.send(new DescribeReplicationGroupsCommand({}));
        if (!ReplicationGroups) {
            throw new Error(`Invalid response from AWS.`);
        }
        const ClusterModeDisabled = ReplicationGroups.map(cluster => parseElasticacheResponse(cluster)).filter(cluster => cluster.clusterMode === 'disabled');
        const ClusterModeEnabled = ReplicationGroups.map(cluster => parseElasticacheResponse(cluster)).filter(cluster => cluster.clusterMode === 'enabled');
        return [ClusterModeEnabled, ClusterModeDisabled];
    });
}
export function getReplicationGroup({ identifier, }) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const { ReplicationGroups } = yield elasticacheClient.send(new DescribeReplicationGroupsCommand({ ReplicationGroupId: identifier }));
            if (!ReplicationGroups) {
                throw new Error(`Invalid response from AWS.`);
            }
            return ReplicationGroups.map(cluster => parseElasticacheResponse(cluster))[0];
        }
        catch (error) {
            if (error instanceof AwsNotFoundError) {
                return undefined;
            }
            throw error;
        }
    });
}
export function getDescribedreplicationGroup(replicationGroupIdentifier) {
    return __awaiter(this, void 0, void 0, function* () {
        const cluster = yield elasticacheClient.send(new DescribeReplicationGroupsCommand({
            ReplicationGroupId: replicationGroupIdentifier,
        }));
        if (cluster.ReplicationGroups === undefined ||
            cluster.ReplicationGroups[0] === undefined) {
            throw new Error(`Cluster ${replicationGroupIdentifier} not found`);
        }
        return cluster.ReplicationGroups[0];
    });
}
//# sourceMappingURL=get-elasticache-replication-groups.js.map