var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DescribeSecurityGroupsCommand } from '@aws-sdk/client-ec2';
import { ModifyReplicationGroupCommand, ModifyCacheClusterCommand, } from '@aws-sdk/client-elasticache';
import { ec2Client } from '../ec2/ec2-client.js';
import { AwsError } from '../common/aws-errors.js';
import { elasticacheClient } from './elasticache-client.js';
export function modifyElasticacheReplicationGroup({ identifier, securityGroupIds, cachePreviousSecurityGroups, }) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        if (securityGroupIds.length === 0) {
            const defaultSecurityGroup = getDefaultVpcIdFromSecurityGroup((_a = cachePreviousSecurityGroups[0]) === null || _a === void 0 ? void 0 : _a.SecurityGroupId);
            const resolved = yield defaultSecurityGroup;
            if (resolved !== undefined) {
                securityGroupIds.push(resolved);
            }
        }
        yield elasticacheClient.send(new ModifyReplicationGroupCommand({
            ReplicationGroupId: identifier,
            SecurityGroupIds: securityGroupIds,
            ApplyImmediately: true,
        }));
    });
}
// Because of a bug in the elasticache API when a cluster is created with no specified security groups ,
// it appears it has none when in reality it's assigned the default vpc's security group.
// this is a workaround for the case in which the basti security groups is the only one in the cluster's.
// The elasticache team has been alerted about the bug.
function getDefaultVpcIdFromSecurityGroup(SecurityGroupId) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        if (SecurityGroupId === undefined)
            throw new AwsError('Security group not found');
        let params = {
            GroupIds: [SecurityGroupId],
        };
        const securityGroupDescription = yield ec2Client.send(new DescribeSecurityGroupsCommand(params));
        const vpcId = (_a = securityGroupDescription.SecurityGroups[0]) === null || _a === void 0 ? void 0 : _a.VpcId;
        if (vpcId !== undefined) {
            params = {
                Filters: [
                    { Name: 'vpc-id', Values: [vpcId] },
                    { Name: 'group-name', Values: ['default'] },
                ],
            };
            const defaultSecurityGroup = yield ec2Client.send(new DescribeSecurityGroupsCommand(params));
            return defaultSecurityGroup.SecurityGroups[0].GroupId;
        }
    });
}
export function modifyElasticacheMemcachedCluster({ identifier, securityGroupIds, cachePreviousSecurityGroups, }) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        if (securityGroupIds.length === 0) {
            const defaultSecurityGroup = getDefaultVpcIdFromSecurityGroup((_a = cachePreviousSecurityGroups[0]) === null || _a === void 0 ? void 0 : _a.SecurityGroupId);
            const resolved = yield defaultSecurityGroup;
            if (resolved !== undefined) {
                securityGroupIds.push(resolved);
            }
        }
        yield elasticacheClient.send(new ModifyCacheClusterCommand({
            CacheClusterId: identifier,
            SecurityGroupIds: securityGroupIds,
            ApplyImmediately: true,
        }));
    });
}
//# sourceMappingURL=modify-elasticache-clusters.js.map