import { z } from 'zod';
import { AwsError } from '../common/aws-errors.js';
export function parseElasticacheMemcachedCacheNode(cacheCluster, identifier) {
    if (cacheCluster.CacheNodes === undefined) {
        throw new AwsError('unexpected error');
    }
    const updatedCluster = Object.assign(Object.assign({}, cacheCluster), { nodeIdentifier: identifier });
    return parseMemcachedCacheClusteWithSpecificNoderResponse(updatedCluster);
}
export const parseMemcachedCacheClusterResponse = z
    .object({
    CacheClusterId: z.string(),
    CacheNodes: z.array(z.object({
        CacheNodeId: z.string(),
        Endpoint: z.object({
            Address: z.string(),
            Port: z.number(),
        }),
    })),
    CacheSubnetGroupName: z.string(),
    SecurityGroups: z
        .array(z.object({
        SecurityGroupId: z.string(),
    }))
        .default([]),
})
    .transform(response => {
    var _a;
    return ({
        identifier: response.CacheClusterId,
        host: response.CacheNodes[0].Endpoint.Address,
        port: response.CacheNodes[0].Endpoint.Port,
        type: 'memcached',
        cacneNodes: [],
        securityGroups: (_a = response.SecurityGroups.map(sg => sg.SecurityGroupId)) !== null && _a !== void 0 ? _a : [],
        subnetGroupName: response.CacheSubnetGroupName,
        clusterId: response.CacheClusterId,
    });
}).parse;
export const parseMemcachedCacheClusteWithSpecificNoderResponse = z
    .object({
    CacheClusterId: z.string(),
    ConfigurationEndpoint: z.object({
        Address: z.string(),
        Port: z.number(),
    }),
    Engine: z.string(),
    CacheNodes: z.any(),
    CacheSubnetGroupName: z.string(),
    SecurityGroups: z
        .array(z.object({
        SecurityGroupId: z.string(),
    }))
        .default([]),
    nodeIdentifier: z.string(),
})
    .transform(response => {
    var _a;
    return ({
        identifier: response.nodeIdentifier,
        host: response.ConfigurationEndpoint.Address,
        port: response.ConfigurationEndpoint.Port,
        type: 'memcached',
        cacneNodes: response.CacheNodes,
        securityGroups: (_a = response.SecurityGroups.map(sg => sg.SecurityGroupId)) !== null && _a !== void 0 ? _a : [],
        subnetGroupName: response.CacheSubnetGroupName,
        clusterId: response.CacheClusterId,
    });
}).parse;
//# sourceMappingURL=parse-elasticache-memcached-response.js.map