var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { CreateRoleCommand, waitUntilRoleExists } from '@aws-sdk/client-iam';
import { COMMON_WAITER_CONFIG } from '../common/waiter-config.js';
import { handleWaiterError } from '../common/waiter-error.js';
import { createIamInlinePolicy } from './create-iam-inline-policy.js';
import { attachIamPolicy } from './attach-iam-policy.js';
import { iamClient } from './iam-client.js';
import { parseRoleResponse } from './parse-iam-response.js';
export function createIamRole({ name, path, principalService, managedPolicies, inlinePolicies, tags, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const { Role } = yield iamClient.send(new CreateRoleCommand({
            RoleName: name,
            Path: path,
            AssumeRolePolicyDocument: formatAssumeRolePolicyDocument(principalService),
            Tags: tags === null || tags === void 0 ? void 0 : tags.map(tag => ({ Key: tag.key, Value: tag.value })),
        }));
        if (!Role) {
            throw new Error(`Invalid response from AWS.`);
        }
        const role = parseRoleResponse(Role);
        yield handleWaiterError(() => __awaiter(this, void 0, void 0, function* () {
            return yield waitUntilRoleExists(Object.assign(Object.assign({}, COMMON_WAITER_CONFIG), { client: iamClient.client }), { RoleName: role.name });
        }));
        if (managedPolicies) {
            yield Promise.all(managedPolicies.map((policy) => __awaiter(this, void 0, void 0, function* () {
                return yield attachIamPolicy({
                    roleName: role.name,
                    policyArn: formatManagedPolicyArn(policy),
                });
            })));
        }
        if (inlinePolicies) {
            yield Promise.all(inlinePolicies.map((policy) => __awaiter(this, void 0, void 0, function* () {
                return yield createIamInlinePolicy({
                    roleName: role.name,
                    policyName: policy.name,
                    policyDocument: policy.document,
                });
            })));
        }
        return role;
    });
}
function formatAssumeRolePolicyDocument(principalService) {
    return JSON.stringify({
        Version: '2012-10-17',
        Statement: [
            {
                Action: 'sts:AssumeRole',
                Effect: 'Allow',
                Sid: '',
                Principal: {
                    Service: principalService,
                },
            },
        ],
    });
}
function formatManagedPolicyArn(name) {
    return `arn:aws:iam::aws:policy/${name}`;
}
//# sourceMappingURL=create-iam-role.js.map