var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GetParameterCommand } from '@aws-sdk/client-ssm';
import { AwsError, AwsNotFoundError } from '../common/aws-errors.js';
import { parseSsmParameter } from './parse-ssm-response.js';
import { ssmClient } from './ssm-client.js';
import { AwsSsmParameterTypes } from './types.js';
export function getSsmParameter({ name, }) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const { Parameter } = yield ssmClient.send(new GetParameterCommand({
                Name: name,
            }));
            if (!Parameter) {
                throw new Error(`Invalid response from AWS.`);
            }
            return parseSsmParameter(Parameter);
        }
        catch (error) {
            if (error instanceof AwsNotFoundError) {
                return undefined;
            }
            throw error;
        }
    });
}
export function getStringSsmParameter(input) {
    return __awaiter(this, void 0, void 0, function* () {
        const parameter = yield getSsmParameter(input);
        if (!parameter) {
            return;
        }
        if (parameter.type !== 'string') {
            throw new AwsWrongSsmParameterTypeError(AwsSsmParameterTypes.STRING, parameter.name, parameter.type);
        }
        return parameter.value;
    });
}
export class AwsWrongSsmParameterTypeError extends AwsError {
    constructor(expectedType, parameterName, parameterType) {
        super(`Expecting SSM parameter "${parameterName}" to be of type "${expectedType}" but got "${parameterType}"`);
        this.expectedType = expectedType;
        this.parameterName = parameterName;
        this.parameterType = parameterType;
    }
}
//# sourceMappingURL=get-ssm-parameter.js.map