var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { StartSessionCommand } from '@aws-sdk/client-ssm';
import { parseStartSsmSessionResponse } from './parse-ssm-response.js';
import { ssmClient } from './ssm-client.js';
export function startSsmPortForwardingSession({ bastionInstanceId, targetHost, targetPort, localPort, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const request = {
            Target: bastionInstanceId,
            DocumentName: 'AWS-StartPortForwardingSessionToRemoteHost',
            Parameters: {
                host: [targetHost],
                portNumber: [String(targetPort)],
                localPortNumber: [String(localPort)],
            },
        };
        const response = yield ssmClient.send(new StartSessionCommand(request));
        return {
            request,
            response: parseStartSsmSessionResponse(response),
            region: yield getSsmClientRegion(),
            endpoint: yield getSsmClientEndpoint(),
        };
    });
}
function getSsmClientRegion() {
    return __awaiter(this, void 0, void 0, function* () {
        const clientRegion = ssmClient.client.config.region;
        return typeof clientRegion === 'string' ? clientRegion : yield clientRegion();
    });
}
function getSsmClientEndpoint() {
    return __awaiter(this, void 0, void 0, function* () {
        return ssmClient.client.config
            .endpointProvider({
            Region: yield ssmClient.client.config.region(),
        })
            .url.toString();
    });
}
//# sourceMappingURL=start-session.js.map