var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { createIamInlinePolicy } from '#src/aws/iam/create-iam-inline-policy.js';
import { createIamRole } from '#src/aws/iam/create-iam-role.js';
import { BASTION_INSTANCE_ROLE_NAME_PREFIX, BASTION_INSTANCE_ROLE_PATH, } from './bastion.js';
export function createBastionRole({ bastionId, tags, }) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield createIamRole({
            name: `${BASTION_INSTANCE_ROLE_NAME_PREFIX}-${bastionId}`,
            path: BASTION_INSTANCE_ROLE_PATH,
            principalService: 'ec2.amazonaws.com',
            tags,
        });
    });
}
export function createBastionRoleInlinePolicies({ bastionRoleName, bastionInstanceId, }) {
    return __awaiter(this, void 0, void 0, function* () {
        yield createIamInlinePolicy({
            roleName: bastionRoleName,
            policyName: 'session-manager-access',
            policyDocument: getSessionManagerAccessPolicy(),
        });
        yield createIamInlinePolicy({
            roleName: bastionRoleName,
            policyName: 'ec2-instance-access',
            policyDocument: getAwsInstanceAccessPolicy(bastionInstanceId),
        });
    });
}
function getSessionManagerAccessPolicy() {
    // Based on https://docs.aws.amazon.com/systems-manager/latest/userguide/getting-started-create-iam-instance-profile.html
    return JSON.stringify({
        Version: '2012-10-17',
        Statement: [
            {
                Effect: 'Allow',
                Action: [
                    'ssm:UpdateInstanceInformation',
                    'ssmmessages:CreateControlChannel',
                    'ssmmessages:CreateDataChannel',
                    'ssmmessages:OpenControlChannel',
                    'ssmmessages:OpenDataChannel',
                ],
                Resource: '*',
            },
        ],
    });
}
function getAwsInstanceAccessPolicy(bastionInstanceId) {
    return JSON.stringify({
        Version: '2012-10-17',
        Statement: [
            {
                Effect: 'Allow',
                Action: ['ec2:DescribeInstances'],
                Resource: '*', // ec2:DescribeInstances does not support resource-level permissions
            },
            {
                Effect: 'Allow',
                Action: ['ec2:CreateTags'],
                Resource: `arn:aws:ec2:*:*:instance/${bastionInstanceId}`,
            },
        ],
    });
}
//# sourceMappingURL=create-bastion-role.js.map