var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AwsNoRootVolumeAttachedError } from '../aws/ec2/ec2-errors.js';
import { startEc2Instance } from '../aws/ec2/start-ec2-instance.js';
import { waitEc2InstanceIsRunning, waitEc2InstanceIsStopped, } from '../aws/ec2/wait-ec2-instance.js';
import { UnexpectedStateError } from '../common/runtime-errors.js';
import { StartingInstanceError } from './bastion-errors.js';
export function ensureBastionRunning({ bastion, hooks, }) {
    var _a, _b, _c, _d, _e, _f, _g;
    return __awaiter(this, void 0, void 0, function* () {
        const { instance, state } = bastion;
        switch (state) {
            case 'running':
                (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onInstanceStarted) === null || _a === void 0 ? void 0 : _a.call(hooks);
                return;
            case 'pending':
                (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onWaitingInstanceToStart) === null || _b === void 0 ? void 0 : _b.call(hooks);
                yield waitEc2InstanceIsRunning({ instanceId: instance.id });
                (_c = hooks === null || hooks === void 0 ? void 0 : hooks.onInstanceStarted) === null || _c === void 0 ? void 0 : _c.call(hooks);
                return;
            case 'updating':
                (_d = hooks === null || hooks === void 0 ? void 0 : hooks.onWaitingInstanceToUpdate) === null || _d === void 0 ? void 0 : _d.call(hooks);
                yield waitEc2InstanceIsStopped({ instanceId: instance.id });
            // eslint-disable-next-line no-fallthrough
            case 'stopping':
                (_e = hooks === null || hooks === void 0 ? void 0 : hooks.onWaitingInstanceToStop) === null || _e === void 0 ? void 0 : _e.call(hooks);
                yield waitEc2InstanceIsStopped({ instanceId: instance.id });
            // eslint-disable-next-line no-fallthrough
            case 'stopped':
                (_f = hooks === null || hooks === void 0 ? void 0 : hooks.onStartingInstance) === null || _f === void 0 ? void 0 : _f.call(hooks);
                yield startInstance(instance);
                (_g = hooks === null || hooks === void 0 ? void 0 : hooks.onInstanceStarted) === null || _g === void 0 ? void 0 : _g.call(hooks);
                return;
            default:
                throw new Error(`Unexpected instance state ${instance.state}`);
        }
    });
}
function startInstance(instance) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield startEc2Instance({ instanceId: instance.id });
        }
        catch (error) {
            if (error instanceof AwsNoRootVolumeAttachedError) {
                error = new UnexpectedStateError(error);
            }
            throw new StartingInstanceError(instance.id, error);
        }
    });
}
//# sourceMappingURL=ensure-bastion-running.js.map