var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { InstanceStateName } from '@aws-sdk/client-ec2';
import { getEc2Instances } from '../aws/ec2/get-ec2-instances.js';
import { getSecurityGroups } from '../aws/ec2/get-security-groups.js';
import { getIamRoles } from '../aws/iam/get-iam-role.js';
import { getInstanceProfiles } from '../aws/iam/get-instance-profiles.js';
import { BASTION_INSTANCE_ID_TAG_NAME, BASTION_INSTANCE_PROFILE_PATH, BASTION_INSTANCE_ROLE_PATH, BASTION_INSTANCE_SECURITY_GROUP_NAME_PREFIX, } from '../bastion/bastion.js';
import { ManagedResourceTypes } from '../common/resource-type.js';
import { TARGET_ACCESS_SECURITY_GROUP_NAME_PREFIX } from '../target/target-input.js';
import { CLEANUP_ORDER } from './managed-resources.js';
const RESOURCE_RETRIEVERS = {
    [ManagedResourceTypes.ACCESS_SECURITY_GROUP]: getAccessSecurityGroups,
    [ManagedResourceTypes.BASTION_SECURITY_GROUP]: getBastionSecurityGroups,
    [ManagedResourceTypes.BASTION_INSTANCE]: getBastionInstances,
    [ManagedResourceTypes.BASTION_INSTANCE_PROFILE]: getBastionInstanceProfiles,
    [ManagedResourceTypes.BASTION_ROLE]: getBastionRoles,
};
export function getResourcesToCleanup({ hooks, }) {
    var _a, _b, _c;
    return __awaiter(this, void 0, void 0, function* () {
        const managedResources = {};
        for (const resourceGroup of CLEANUP_ORDER) {
            try {
                (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onRetrievingResources) === null || _a === void 0 ? void 0 : _a.call(hooks, resourceGroup);
                managedResources[resourceGroup] = yield RESOURCE_RETRIEVERS[resourceGroup]();
                (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onResourcesRetrieved) === null || _b === void 0 ? void 0 : _b.call(hooks, resourceGroup);
            }
            catch (error) {
                (_c = hooks === null || hooks === void 0 ? void 0 : hooks.onRetrievalFailed) === null || _c === void 0 ? void 0 : _c.call(hooks, resourceGroup, error);
                managedResources[resourceGroup] = [];
            }
        }
        return managedResources;
    });
}
function getAccessSecurityGroups() {
    return __awaiter(this, void 0, void 0, function* () {
        const securityGroups = yield getSecurityGroups({
            names: [`${TARGET_ACCESS_SECURITY_GROUP_NAME_PREFIX}*`],
        });
        return securityGroups.map(securityGroup => securityGroup.id);
    });
}
function getBastionSecurityGroups() {
    return __awaiter(this, void 0, void 0, function* () {
        const securityGroups = yield getSecurityGroups({
            names: [`${BASTION_INSTANCE_SECURITY_GROUP_NAME_PREFIX}*`],
        });
        return securityGroups.map(securityGroup => securityGroup.id);
    });
}
function getBastionInstances() {
    return __awaiter(this, void 0, void 0, function* () {
        const bastionInstances = yield getEc2Instances({
            tags: [
                {
                    key: BASTION_INSTANCE_ID_TAG_NAME,
                    value: '*',
                },
            ],
            states: [
                InstanceStateName.pending,
                InstanceStateName.running,
                InstanceStateName.stopping,
                InstanceStateName.stopped,
            ],
        });
        return bastionInstances.map(instance => instance.id);
    });
}
function getBastionRoles() {
    return __awaiter(this, void 0, void 0, function* () {
        const iamRoles = yield getIamRoles({ path: BASTION_INSTANCE_ROLE_PATH });
        return iamRoles.map(role => role.name);
    });
}
function getBastionInstanceProfiles() {
    return __awaiter(this, void 0, void 0, function* () {
        const instanceProfiles = yield getInstanceProfiles({
            path: BASTION_INSTANCE_PROFILE_PATH,
        });
        return instanceProfiles.map(profile => profile.name);
    });
}
//# sourceMappingURL=get-resources-to-cleanup.js.map