var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { CLEANUP_ORDER } from '#src/cleanup/managed-resources.js';
import { cli } from '#src/common/cli.js';
import { fmt } from '#src/common/fmt.js';
import { ManagedResourceTypes } from '#src/common/resource-type.js';
import { EarlyExitError } from '../../error/early-exit-error.js';
const RESOURCE_GROUP_TITLES = {
    [ManagedResourceTypes.ACCESS_SECURITY_GROUP]: 'Access security groups',
    [ManagedResourceTypes.BASTION_SECURITY_GROUP]: 'Bastion security groups',
    [ManagedResourceTypes.BASTION_INSTANCE]: 'Bastion EC2 instances',
    [ManagedResourceTypes.BASTION_INSTANCE_PROFILE]: 'Bastion IAM instance profiles',
    [ManagedResourceTypes.BASTION_ROLE]: 'Bastion IAM roles',
};
export function confirmCleanup({ resources, }) {
    return __awaiter(this, void 0, void 0, function* () {
        printResources(resources);
        const { confirm } = yield cli.prompt({
            type: 'confirm',
            name: 'confirm',
            message: 'Proceed to cleanup?',
            default: true,
        });
        if (!confirm) {
            throw new EarlyExitError('Cleanup aborted');
        }
    });
}
function printResources(resources) {
    const subCli = cli.createSubInstance({ indent: 2 });
    cli.info('The following resources are going to be deleted:');
    CLEANUP_ORDER.filter(group => resources[group].length > 0).forEach(group => {
        cli.out(`${RESOURCE_GROUP_TITLES[group]}`);
        subCli.out(fmt.list(resources[group].map(resource => fmt.value(resource))));
    });
}
//# sourceMappingURL=confirm-cleanup.js.map