var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as cleanupOps from '#src/cleanup/get-resources-to-cleanup.js';
import { cli } from '#src/common/cli.js';
import { fmt } from '#src/common/fmt.js';
import { ManagedResourceTypes } from '#src/common/resource-type.js';
import { getErrorDetail } from '../../error/get-error-detail.js';
const RESOURCE_GROUP_NAMES = {
    [ManagedResourceTypes.ACCESS_SECURITY_GROUP]: 'Access security groups',
    [ManagedResourceTypes.BASTION_SECURITY_GROUP]: 'Bastion security groups',
    [ManagedResourceTypes.BASTION_INSTANCE]: 'Bastion EC2 instances',
    [ManagedResourceTypes.BASTION_INSTANCE_PROFILE]: 'Bastion IAM instance profiles',
    [ManagedResourceTypes.BASTION_ROLE]: 'Bastion IAM roles',
};
export function getResourcesToCleanup() {
    return __awaiter(this, void 0, void 0, function* () {
        const subCli = cli.createSubInstance({ indent: 2 });
        let partialFailure = false;
        cli.out(`${fmt.green('❯')} Retrieving Basti-managed resources:`);
        const managedResources = yield cleanupOps.getResourcesToCleanup({
            hooks: {
                onRetrievingResources: group => subCli.progressStart(RESOURCE_GROUP_NAMES[group]),
                onResourcesRetrieved: () => subCli.progressSuccess(),
                onRetrievalFailed: (_, error) => {
                    partialFailure = true;
                    const warnText = getErrorDetail(error);
                    subCli.progressWarn({ warnText });
                },
            },
        });
        partialFailure
            ? cli.progressWarn({
                text: 'Managed resources retrieved',
                warnText: 'Not all the resources were retrieved. The account cannot be fully cleaned up',
            })
            : cli.progressSuccess('Managed resources retrieved');
        return managedResources;
    });
}
//# sourceMappingURL=get-resources-to-cleanup.js.map