var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { getDbCluster } from '#src/aws/rds/get-db-clusters.js';
import { getDbInstance } from '#src/aws/rds/get-db-instances.js';
import { TargetTypes } from '#src/common/resource-type.js';
import { getReplicationGroup } from '#src/aws/elasticache/get-elasticache-replication-groups.js';
import { getCacheCluster } from '#src/aws/elasticache/get-elasticache-cache-clusters.js';
import { getMemcachedCluster, getMemcachedNode, } from '#src/aws/elasticache/get-elasticache-memcached-clusters.js';
import { orThrow } from './get-or-throw.js';
export function hydrateAwsTarget(targetInput) {
    return __awaiter(this, void 0, void 0, function* () {
        if ('rdsInstanceId' in targetInput) {
            return {
                dbInstance: yield orThrow(() => __awaiter(this, void 0, void 0, function* () {
                    return yield getDbInstance({
                        identifier: targetInput.rdsInstanceId,
                    });
                }), TargetTypes.RDS_INSTANCE, targetInput.rdsInstanceId),
            };
        }
        if ('rdsClusterId' in targetInput) {
            return {
                dbCluster: yield orThrow(() => __awaiter(this, void 0, void 0, function* () {
                    return yield getDbCluster({
                        identifier: targetInput.rdsClusterId,
                    });
                }), TargetTypes.RDS_CLUSTER, targetInput.rdsClusterId),
            };
        }
        if ('elasticacheRedisClusterId' in targetInput) {
            return {
                elasticacheRedisCluster: yield orThrow(() => __awaiter(this, void 0, void 0, function* () {
                    return yield getReplicationGroup({
                        identifier: targetInput.elasticacheRedisClusterId,
                    });
                }), TargetTypes.ELASTICACHE_REDIS_CLUSTER, targetInput.elasticacheRedisClusterId),
            };
        }
        if ('elasticacheRedisNodeId' in targetInput) {
            return {
                elasticacheRedisCluster: yield orThrow(() => __awaiter(this, void 0, void 0, function* () {
                    return yield getCacheCluster({
                        identifier: targetInput.elasticacheRedisNodeId,
                    });
                }), TargetTypes.ELASTICACHE_REDIS_NODE, targetInput.elasticacheRedisNodeId),
            };
        }
        if ('elasticacheMemcachedNodeId' in targetInput) {
            return {
                elasticacheMemcachedCluster: yield orThrow(() => __awaiter(this, void 0, void 0, function* () { return yield getMemcachedNode(targetInput.elasticacheMemcachedNodeId); }), TargetTypes.ELASTICACHE_MEMCACHED_NODE, targetInput.elasticacheMemcachedNodeId),
            };
        }
        return {
            elasticacheMemcachedCluster: yield orThrow(() => __awaiter(this, void 0, void 0, function* () { return yield getMemcachedCluster(targetInput.elasticacheMemcachedClusterId); }), TargetTypes.ELASTICACHE_MEMCACHED_CLUSTER, targetInput.elasticacheMemcachedClusterId),
        };
    });
}
//# sourceMappingURL=hydrate-aws-target.js.map