var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { createConnectTarget } from '#src/target/create-connect-target.js';
import { cli } from '#src/common/cli.js';
import { promptForCustomTargetVpc } from '../common/prompt-for-custom-target-vpc.js';
import { promptForAwsTarget } from '../common/prompt-for-aws-target.js';
import { hydrateAwsTarget } from '../common/hydrate-aws-target.js';
import { handleOperation } from '../common/handle-operation.js';
import { selectPort } from './select-port.js';
const IP_REGEX = /^((25[0-5]|(2[0-4]|1\d|[1-9]|)\d)\.?\b){4}$/;
const DOMAIN_NAME_REGEX = /^(?:[\da-z](?:[\da-z-]{0,61}[\da-z])?\.)+[\da-z][\da-z-]{0,61}[\da-z]$/;
export function selectConnectTarget(dehydratedInput) {
    return __awaiter(this, void 0, void 0, function* () {
        const targetInput = dehydratedInput
            ? yield handleOperation('Retrieving specified target', () => __awaiter(this, void 0, void 0, function* () { return yield hydrateInput(dehydratedInput); }))
            : yield promptForTarget();
        return createConnectTarget(targetInput);
    });
}
function hydrateInput(dehydratedInput) {
    return __awaiter(this, void 0, void 0, function* () {
        const targetInput = 'customTargetVpcId' in dehydratedInput
            ? {
                custom: {
                    vpcId: dehydratedInput.customTargetVpcId,
                    host: dehydratedInput.customTargetHost,
                    port: dehydratedInput.customTargetPort,
                },
            }
            : yield hydrateAwsTarget(dehydratedInput);
        return Object.assign(Object.assign({}, targetInput), { awsClientConfig: dehydratedInput.awsClientConfig });
    });
}
function promptForTarget() {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        return ((_a = (yield promptForAwsTarget('connect'))) !== null && _a !== void 0 ? _a : (yield promptForCustomTarget()));
    });
}
function promptForCustomTarget() {
    return __awaiter(this, void 0, void 0, function* () {
        const vpcId = yield promptForCustomTargetVpc();
        const { host } = yield cli.prompt({
            type: 'input',
            name: 'host',
            message: 'Target host name / IP address',
            validate: validateHost,
        });
        const port = yield selectPort('Target port number');
        return { custom: { vpcId, host, port } };
    });
}
function validateHost(input) {
    if (input === undefined ||
        typeof input !== 'string' ||
        (!IP_REGEX.test(input) && !DOMAIN_NAME_REGEX.test(input))) {
        return 'Invalid host name / IP address';
    }
    return true;
}
//# sourceMappingURL=select-connect-target.js.map