var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AwsTooManySecurityGroupsAttachedError } from '#src/aws/common/aws-errors.js';
import { cli } from '#src/common/cli.js';
import { fmt } from '#src/common/fmt.js';
import { AccessSecurityGroupCreationError, AccessSecurityGroupAttachmentError, } from '#src/target/target-errors.js';
import { detailProvider } from '../../error/get-error-detail.js';
import { OperationError } from '../../error/operation-error.js';
export function allowTargetAccess({ target, bastion, tags, }) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!target.allowAccess) {
            cli.info(`Please, make sure your target is accessible from the bastion instance. Bastion security group: ${fmt.value(bastion.securityGroupName)}`);
            return;
        }
        const subCli = cli.createSubInstance({ indent: 2 });
        try {
            cli.out(`${fmt.green('❯')} Configuring target access:`);
            yield target.allowAccess({
                bastion,
                tags,
                hooks: {
                    onCreatingSecurityGroup: () => subCli.progressStart('Creating access security group'),
                    onSecurityGroupCreated: sgId => subCli.progressSuccess(`Access security group created: ${fmt.value(sgId)}`),
                    onAttachingSecurityGroup: () => subCli.progressStart('Attaching security group to your target'),
                    onSecurityGroupAttached: () => subCli.progressSuccess('Access security group attached'),
                },
            });
            cli.success(`The target has been initialized to use with Basti. It's recommended to give AWS a few minutes to propagate the changes before connecting with the ${fmt.code('basti connect')} command`);
        }
        catch (error) {
            subCli.progressFailure();
            throw OperationError.fromError({
                operationName: 'Configuring target access',
                error,
                dirtyOperation: true,
                detailProviders: [
                    detailProvider(AccessSecurityGroupCreationError, () => "Can't create access security group for target"),
                    detailProvider(AccessSecurityGroupAttachmentError, () => "Can't attach access security group to target"),
                    detailProvider(AwsTooManySecurityGroupsAttachedError, () => 'Security group associations limit reached. Please, remove a security group from your target and try again'),
                ],
            });
        }
    });
}
//# sourceMappingURL=allow-target-access.js.map