import { OperationError } from '../error/operation-error.js';
import { isRdsClusterTargetConfig, isRdsInstanceTargetConfig, isElasticacheRedisClusterTargetConfig, isElasticacheRedisNodeTargetConfig, isElasticacheMemcachedClusterTargetConfig, isElasticacheMemcachedNodeTargetConfig, } from './config-parser.js';
export function getConnectCommandInputFromConfig(config, connection) {
    var _a, _b;
    if (!config) {
        throw OperationError.fromErrorMessage({
            operationName: 'Resoling connection from configuration file',
            message: 'No configuration file found',
        });
    }
    const connectionConfig = (_a = config.connections) === null || _a === void 0 ? void 0 : _a[connection];
    if (!connectionConfig) {
        throw OperationError.fromErrorMessage({
            operationName: 'Resolving connection from configuration file',
            message: `No connection with name "${connection}" found in configuration file`,
        });
    }
    const connectionTarget = typeof connectionConfig.target === 'object'
        ? connectionConfig.target
        : (_b = config.targets) === null || _b === void 0 ? void 0 : _b[connectionConfig.target];
    if (!connectionTarget) {
        throw OperationError.fromErrorMessage({
            operationName: 'Resoling connection from configuration file',
            message: `No target with name "${connectionConfig.target}" found in configuration file`,
        });
    }
    const awsClientConfig = connectionTarget.awsProfile !== undefined ||
        connectionTarget.awsRegion !== undefined
        ? {
            profile: connectionTarget.awsProfile,
            region: connectionTarget.awsRegion,
        }
        : undefined;
    return {
        target: isRdsInstanceTargetConfig(connectionTarget)
            ? {
                rdsInstanceId: connectionTarget.rdsInstance,
                awsClientConfig,
            }
            : isRdsClusterTargetConfig(connectionTarget)
                ? {
                    rdsClusterId: connectionTarget.rdsCluster,
                    awsClientConfig,
                }
                : isElasticacheRedisClusterTargetConfig(connectionTarget)
                    ? {
                        elasticacheRedisClusterId: connectionTarget.elasticacheRedisCluster,
                        awsClientConfig,
                    }
                    : isElasticacheRedisNodeTargetConfig(connectionTarget)
                        ? {
                            elasticacheRedisNodeId: connectionTarget.elasticacheRedisNode,
                            awsClientConfig,
                        }
                        : isElasticacheMemcachedClusterTargetConfig(connectionTarget)
                            ? {
                                elasticacheMemcachedClusterId: connectionTarget.elasticacheMemcachedCluster,
                                awsClientConfig,
                            }
                            : isElasticacheMemcachedNodeTargetConfig(connectionTarget)
                                ? {
                                    elasticacheMemcachedNodeId: connectionTarget.elasticacheMemcachedNode,
                                    awsClientConfig,
                                }
                                : {
                                    customTargetVpcId: connectionTarget.customTargetVpc,
                                    customTargetHost: connectionTarget.customTargetHost,
                                    customTargetPort: connectionTarget.customTargetPort,
                                    awsClientConfig,
                                },
        localPort: connectionConfig.localPort,
    };
}
//# sourceMappingURL=get-command-input.js.map