/* eslint-disable unicorn/no-process-exit */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { cli } from '#src/common/cli.js';
import { getErrorMessage, RuntimeError } from '#src/common/runtime-errors.js';
import { EarlyExitError } from './early-exit-error.js';
import { OperationError } from './operation-error.js';
export function withErrorHandling(handler) {
    return (...args) => __awaiter(this, void 0, void 0, function* () {
        try {
            return yield handler(...args);
        }
        catch (error) {
            handleError(error);
        }
    });
}
export function handleAsyncErrors() {
    process.on('uncaughtException', error => {
        handleError(error);
    });
}
function handleError(error) {
    cli.exitContext();
    if (error instanceof EarlyExitError) {
        cli.info(error.message);
        error.debugInfo !== undefined && cli.debug(error.debugInfo);
        process.exit(0);
    }
    if (error instanceof OperationError) {
        cli.error(error.operationErrorMessage);
        cli.debug(error.getDeepStack());
        process.exit(1);
    }
    cli.error(`Unexpected error: ${getErrorMessage(error)}`);
    if (error instanceof RuntimeError) {
        cli.debug(error.getDeepStack());
    }
    else if (error instanceof Error && error.stack !== undefined) {
        cli.debug(error.stack);
    }
    process.exit(1);
}
//# sourceMappingURL=handle-error.js.map