import { fmt } from '#src/common/fmt.js';
import { RuntimeError } from '#src/common/runtime-errors.js';
import { getErrorDetail } from './get-error-detail.js';
export class OperationError extends RuntimeError {
    constructor(operationName, message, cause, dirtyOperation) {
        super(message, cause);
        this.operationErrorMessage = getOperationErrorMessage(operationName, message, dirtyOperation);
    }
    static fromErrorMessage({ operationName, message, dirtyOperation, }) {
        return new OperationError(operationName, message, undefined, dirtyOperation);
    }
    static fromError({ operationName, error, detailProviders, dirtyOperation, }) {
        return new OperationError(operationName, getErrorDetail(error, detailProviders), error, dirtyOperation);
    }
}
function getOperationErrorMessage(operationName, message, shouldCleanup) {
    const dirtyOperationMessage = shouldCleanup === true
        ? `. This operation might have already created AWS resources. Please, run ${fmt.code('basti cleanup')} before retrying`
        : '';
    return (`Error ${fmt.lower(operationName)}. ${fmt.capitalize(message)}` +
        dirtyOperationMessage);
}
//# sourceMappingURL=operation-error.js.map