import { isOptionInArgs } from './yargs-check.js';
export function conflictingOptions(...options) {
    return args => {
        const presentArgumentGroups = options
            .map(option => toOptionGroup(option))
            .filter(group => isOptionGroupInArgs(group, args));
        if (presentArgumentGroups.length > 1) {
            throw new Error(`The following options are mutually exclusive: ${formatList(options)}`);
        }
        return true;
    };
}
function toOptionGroup(option) {
    return Array.isArray(option) ? option : [option];
}
function isOptionGroupInArgs(optionGroup, args) {
    return optionGroup.some(option => isOptionInArgs(option, args));
}
function formatList(options) {
    return options
        .map(option => (Array.isArray(option) ? `[${option.join(', ')}]` : option))
        .join(', ');
}
//# sourceMappingURL=conflicting-options-check.js.map