var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { startSsmPortForwardingSession } from '../aws/ssm/start-session.js';
import { retry } from '../common/retry.js';
import { AwsSsmInstanceNotConnectedError } from '../aws/ssm/ssm-errors.js';
import { startBastionUsageMarker } from './start-bastion-usage-marker.js';
import { startSessionManagerPluginProcess } from './start-session-manager-plugin-process.js';
export function startPortForwardingSession({ target, bastionInstanceId, localPort, hooks, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const stopUsageMarker = startBastionUsageMarker({
            bastionInstanceId,
            hooks: {
                onMarkingError: hooks === null || hooks === void 0 ? void 0 : hooks.onMarkingError,
            },
        });
        try {
            const targetHost = yield target.getHost();
            const targetPort = yield target.getPort();
            const sessionDescriptor = yield startSessionWithRetries(bastionInstanceId, targetHost, targetPort, localPort);
            yield startSessionManagerPluginProcess({
                sessionDescriptor,
                hooks: {
                    onExit: exitDescription => {
                        var _a;
                        stopUsageMarker();
                        (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onSessionEnded) === null || _a === void 0 ? void 0 : _a.call(hooks, exitDescription);
                    },
                    onErrorExit: error => {
                        var _a;
                        stopUsageMarker();
                        (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onSessionError) === null || _a === void 0 ? void 0 : _a.call(hooks, error);
                    },
                },
            });
        }
        catch (error) {
            stopUsageMarker();
            throw error;
        }
    });
}
function startSessionWithRetries(bastionInstanceId, targetHost, targetPort, localPort) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield retry(() => __awaiter(this, void 0, void 0, function* () {
            return yield startSsmPortForwardingSession({
                bastionInstanceId,
                targetHost,
                targetPort,
                localPort,
            });
        }), {
            delay: 3000,
            maxRetries: 30,
            shouldRetry: isTargetNotConnectedError,
        });
    });
}
function isTargetNotConnectedError(error) {
    return error instanceof AwsSsmInstanceNotConnectedError;
}
//# sourceMappingURL=start-port-forwarding-session.js.map