var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { getCacheClusterSubnetGroup } from '#src/aws/elasticache/get-cache-cluster-subnet-group.js';
import { getDescribedCacheCluster } from '#src/aws/elasticache/get-elasticache-cache-clusters.js';
import { getDescribedreplicationGroup } from '#src/aws/elasticache/get-elasticache-replication-groups.js';
import { AwsError } from '#src/aws/common/aws-errors.js';
import { ConnectTargetBase } from '../connect-target.js';
export class ElasticacheRedisClusterConnectTarget extends ConnectTargetBase {
    constructor(input) {
        super(input);
        this.elasticacheRedisCluster = input.elasticacheRedisCluster;
        this.detaliedInformationCluster = this.getDescribedCacheCluster();
        this.elasticacheSubnetGroupName = this.getSubnetGroupName();
    }
    getHost() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.elasticacheRedisCluster.host;
        });
    }
    getPort() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.elasticacheRedisCluster.port;
        });
    }
    getSecurityGroupIds() {
        return __awaiter(this, void 0, void 0, function* () {
            const detailedCache = yield this.detaliedInformationCluster;
            const array = [];
            if (detailedCache.SecurityGroups === undefined) {
                return array;
            }
            const unfiltered = detailedCache.SecurityGroups.map(element => {
                return element.SecurityGroupId !== undefined
                    ? element.SecurityGroupId
                    : '';
            });
            return unfiltered.filter(Element => {
                return Element !== '';
            });
        });
    }
    getVpcId() {
        return __awaiter(this, void 0, void 0, function* () {
            const awsSubnetGroup = yield this.elasticacheSubnetGroupName;
            if (awsSubnetGroup === undefined) {
                throw new AwsError('No subnet groups');
            }
            const dbSubnetGroup = yield getCacheClusterSubnetGroup({
                name: awsSubnetGroup,
            });
            if (!dbSubnetGroup) {
                throw new Error(`Cluster subnet group "${awsSubnetGroup}" not found`);
            }
            return dbSubnetGroup.vpcId;
        });
    }
    getTargetPort() {
        return this.elasticacheRedisCluster.port;
    }
    getDescribedCacheCluster() {
        return __awaiter(this, void 0, void 0, function* () {
            const cluster = yield getDescribedreplicationGroup(this.elasticacheRedisCluster.replicationGroupId);
            if (cluster.NodeGroups === undefined ||
                cluster.NodeGroups[0] === undefined ||
                cluster.NodeGroups[0].NodeGroupMembers === undefined ||
                cluster.NodeGroups[0].NodeGroupMembers[0] === undefined ||
                cluster.NodeGroups[0].NodeGroupMembers[0].CacheClusterId === undefined)
                throw new AwsError('unexpected Elasticache Response');
            const cacheId = cluster.NodeGroups[0].NodeGroupMembers[0].CacheClusterId;
            return yield getDescribedCacheCluster(cacheId);
        });
    }
    getSubnetGroupName() {
        return __awaiter(this, void 0, void 0, function* () {
            const detailedCache = yield this.detaliedInformationCluster;
            return detailedCache.CacheSubnetGroupName;
        });
    }
}
//# sourceMappingURL=elasticache-redis-cluster-connect-target.js.map