"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateDescribeEvents = void 0;
const DescribeEventsCommand_1 = require("../commands/DescribeEventsCommand");
const ElastiCacheClient_1 = require("../ElastiCacheClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new DescribeEventsCommand_1.DescribeEventsCommand(input), ...args);
};
async function* paginateDescribeEvents(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.Marker = token;
        input["MaxRecords"] = config.pageSize;
        if (config.client instanceof ElastiCacheClient_1.ElastiCacheClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected ElastiCache | ElastiCacheClient");
        }
        yield page;
        const prevToken = token;
        token = page.Marker;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateDescribeEvents = paginateDescribeEvents;
