<!-- generated file, do not edit directly -->

# @aws-sdk/client-rds

[![NPM version](https://img.shields.io/npm/v/@aws-sdk/client-rds/latest.svg)](https://www.npmjs.com/package/@aws-sdk/client-rds)
[![NPM downloads](https://img.shields.io/npm/dm/@aws-sdk/client-rds.svg)](https://www.npmjs.com/package/@aws-sdk/client-rds)

## Description

AWS SDK for JavaScript RDS Client for Node.js, Browser and React Native.

<fullname>Amazon Relational Database Service</fullname>

<p></p>
<p>Amazon Relational Database Service (Amazon RDS) is a web service that makes it easier to set up, operate, and
scale a relational database in the cloud. It provides cost-efficient, resizeable capacity for an industry-standard relational
database and manages common database administration tasks, freeing up developers to focus on what makes their applications
and businesses unique.</p>
<p>Amazon RDS gives you access to the capabilities of a MySQL, MariaDB, PostgreSQL, Microsoft SQL Server,
Oracle, or Amazon Aurora database server. These capabilities mean that the code, applications, and tools
you already use today with your existing databases work with Amazon RDS without modification. Amazon RDS
automatically backs up your database and maintains the database software that powers your DB instance. Amazon RDS
is flexible: you can scale your DB instance's compute resources and storage capacity to meet your
application's demand. As with all Amazon Web Services, there are no up-front investments, and you pay only for
the resources you use.</p>
<p>This interface reference for Amazon RDS contains documentation for a programming or command line interface
you can use to manage Amazon RDS. Amazon RDS is asynchronous, which means that some interfaces might
require techniques such as polling or callback functions to determine when a command has been applied. In this
reference, the parameter descriptions indicate whether a command is applied immediately, on the next instance reboot,
or during the maintenance window. The reference structure is as follows, and we list following some related topics
from the user guide.</p>
<p>
<b>Amazon RDS API Reference</b>
</p>
<ul>
<li>
<p>For the alphabetical list of API actions, see
<a href="https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_Operations.html">API Actions</a>.</p>
</li>
<li>
<p>For the alphabetical list of data types, see
<a href="https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_Types.html">Data Types</a>.</p>
</li>
<li>
<p>For a list of common query parameters, see
<a href="https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/CommonParameters.html">Common Parameters</a>.</p>
</li>
<li>
<p>For descriptions of the error codes, see
<a href="https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/CommonErrors.html">Common Errors</a>.</p>
</li>
</ul>
<p>
<b>Amazon RDS User Guide</b>
</p>
<ul>
<li>
<p>For a summary of the Amazon RDS interfaces, see
<a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Welcome.html#Welcome.Interfaces">Available RDS Interfaces</a>.</p>
</li>
<li>
<p>For more information about how to use the Query API, see
<a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Using_the_Query_API.html">Using the Query API</a>.</p>
</li>
</ul>

## Installing

To install the this package, simply type add or install @aws-sdk/client-rds
using your favorite package manager:

- `npm install @aws-sdk/client-rds`
- `yarn add @aws-sdk/client-rds`
- `pnpm add @aws-sdk/client-rds`

## Getting Started

### Import

The AWS SDK is modulized by clients and commands.
To send a request, you only need to import the `RDSClient` and
the commands you need, for example `AddRoleToDBClusterCommand`:

```js
// ES5 example
const { RDSClient, AddRoleToDBClusterCommand } = require("@aws-sdk/client-rds");
```

```ts
// ES6+ example
import { RDSClient, AddRoleToDBClusterCommand } from "@aws-sdk/client-rds";
```

### Usage

To send a request, you:

- Initiate client with configuration (e.g. credentials, region).
- Initiate command with input parameters.
- Call `send` operation on client with command object as input.
- If you are using a custom http handler, you may call `destroy()` to close open connections.

```js
// a client can be shared by different commands.
const client = new RDSClient({ region: "REGION" });

const params = {
  /** input parameters */
};
const command = new AddRoleToDBClusterCommand(params);
```

#### Async/await

We recommend using [await](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/await)
operator to wait for the promise returned by send operation as follows:

```js
// async/await.
try {
  const data = await client.send(command);
  // process data.
} catch (error) {
  // error handling.
} finally {
  // finally.
}
```

Async-await is clean, concise, intuitive, easy to debug and has better error handling
as compared to using Promise chains or callbacks.

#### Promises

You can also use [Promise chaining](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Using_promises#chaining)
to execute send operation.

```js
client.send(command).then(
  (data) => {
    // process data.
  },
  (error) => {
    // error handling.
  }
);
```

Promises can also be called using `.catch()` and `.finally()` as follows:

```js
client
  .send(command)
  .then((data) => {
    // process data.
  })
  .catch((error) => {
    // error handling.
  })
  .finally(() => {
    // finally.
  });
```

#### Callbacks

We do not recommend using callbacks because of [callback hell](http://callbackhell.com/),
but they are supported by the send operation.

```js
// callbacks.
client.send(command, (err, data) => {
  // process err and data.
});
```

#### v2 compatible style

The client can also send requests using v2 compatible style.
However, it results in a bigger bundle size and may be dropped in next major version. More details in the blog post
on [modular packages in AWS SDK for JavaScript](https://aws.amazon.com/blogs/developer/modular-packages-in-aws-sdk-for-javascript/)

```ts
import * as AWS from "@aws-sdk/client-rds";
const client = new AWS.RDS({ region: "REGION" });

// async/await.
try {
  const data = await client.addRoleToDBCluster(params);
  // process data.
} catch (error) {
  // error handling.
}

// Promises.
client
  .addRoleToDBCluster(params)
  .then((data) => {
    // process data.
  })
  .catch((error) => {
    // error handling.
  });

// callbacks.
client.addRoleToDBCluster(params, (err, data) => {
  // process err and data.
});
```

### Troubleshooting

When the service returns an exception, the error will include the exception information,
as well as response metadata (e.g. request id).

```js
try {
  const data = await client.send(command);
  // process data.
} catch (error) {
  const { requestId, cfId, extendedRequestId } = error.$$metadata;
  console.log({ requestId, cfId, extendedRequestId });
  /**
   * The keys within exceptions are also parsed.
   * You can access them by specifying exception names:
   * if (error.name === 'SomeServiceException') {
   *     const value = error.specialKeyInException;
   * }
   */
}
```

## Getting Help

Please use these community resources for getting help.
We use the GitHub issues for tracking bugs and feature requests, but have limited bandwidth to address them.

- Visit [Developer Guide](https://docs.aws.amazon.com/sdk-for-javascript/v3/developer-guide/welcome.html)
  or [API Reference](https://docs.aws.amazon.com/AWSJavaScriptSDK/v3/latest/index.html).
- Check out the blog posts tagged with [`aws-sdk-js`](https://aws.amazon.com/blogs/developer/tag/aws-sdk-js/)
  on AWS Developer Blog.
- Ask a question on [StackOverflow](https://stackoverflow.com/questions/tagged/aws-sdk-js) and tag it with `aws-sdk-js`.
- Join the AWS JavaScript community on [gitter](https://gitter.im/aws/aws-sdk-js-v3).
- If it turns out that you may have found a bug, please [open an issue](https://github.com/aws/aws-sdk-js-v3/issues/new/choose).

To test your universal JavaScript code in Node.js, browser and react-native environments,
visit our [code samples repo](https://github.com/aws-samples/aws-sdk-js-tests).

## Contributing

This client code is generated automatically. Any modifications will be overwritten the next time the `@aws-sdk/client-rds` package is updated.
To contribute to client you can check our [generate clients scripts](https://github.com/aws/aws-sdk-js-v3/tree/main/scripts/generate-clients).

## License

This SDK is distributed under the
[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0),
see LICENSE for more information.
