"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateDescribeDBSnapshots = void 0;
const DescribeDBSnapshotsCommand_1 = require("../commands/DescribeDBSnapshotsCommand");
const RDS_1 = require("../RDS");
const RDSClient_1 = require("../RDSClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new DescribeDBSnapshotsCommand_1.DescribeDBSnapshotsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.describeDBSnapshots(input, ...args);
};
async function* paginateDescribeDBSnapshots(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.Marker = token;
        input["MaxRecords"] = config.pageSize;
        if (config.client instanceof RDS_1.RDS) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof RDSClient_1.RDSClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected RDS | RDSClient");
        }
        yield page;
        const prevToken = token;
        token = page.Marker;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateDescribeDBSnapshots = paginateDescribeDBSnapshots;
