import { DescribeDBEngineVersionsCommand, } from "../commands/DescribeDBEngineVersionsCommand";
import { RDS } from "../RDS";
import { RDSClient } from "../RDSClient";
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new DescribeDBEngineVersionsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.describeDBEngineVersions(input, ...args);
};
export async function* paginateDescribeDBEngineVersions(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.Marker = token;
        input["MaxRecords"] = config.pageSize;
        if (config.client instanceof RDS) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof RDSClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected RDS | RDSClient");
        }
        yield page;
        const prevToken = token;
        token = page.Marker;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
