import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DBEngineVersion, DeleteCustomDBEngineVersionMessage } from "../models/models_0";
import { RDSClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../RDSClient";
export interface DeleteCustomDBEngineVersionCommandInput extends DeleteCustomDBEngineVersionMessage {
}
export interface DeleteCustomDBEngineVersionCommandOutput extends DBEngineVersion, __MetadataBearer {
}
/**
 * <p>Deletes a custom engine version. To run this command, make sure you meet the following prerequisites:</p>
 *          <ul>
 *             <li>
 *                <p>The CEV must not be the default for RDS Custom. If it is, change the default
 *                 before running this command.</p>
 *             </li>
 *             <li>
 *                <p>The CEV must not be associated with an RDS Custom DB instance, RDS Custom instance snapshot,
 *                 or automated backup of your RDS Custom instance.</p>
 *             </li>
 *          </ul>
 *          <p>Typically, deletion takes a few minutes.</p>
 *          <note>
 *             <p>The MediaImport service that imports files from Amazon S3 to create CEVs isn't integrated with
 *             Amazon Web Services CloudTrail. If you turn on data logging for Amazon RDS in CloudTrail, calls to the
 *             <code>DeleteCustomDbEngineVersion</code> event aren't logged. However, you might see calls from the
 *             API gateway that accesses your Amazon S3 bucket. These calls originate from the MediaImport service for
 *             the <code>DeleteCustomDbEngineVersion</code> event.</p>
 *          </note>
 *          <p>For more information, see <a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/custom-cev.html#custom-cev.delete">
 *             Deleting a CEV</a> in the <i>Amazon RDS User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { RDSClient, DeleteCustomDBEngineVersionCommand } from "@aws-sdk/client-rds"; // ES Modules import
 * // const { RDSClient, DeleteCustomDBEngineVersionCommand } = require("@aws-sdk/client-rds"); // CommonJS import
 * const client = new RDSClient(config);
 * const command = new DeleteCustomDBEngineVersionCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DeleteCustomDBEngineVersionCommandInput} for command's `input` shape.
 * @see {@link DeleteCustomDBEngineVersionCommandOutput} for command's `response` shape.
 * @see {@link RDSClientResolvedConfig | config} for RDSClient's `config` shape.
 *
 */
export declare class DeleteCustomDBEngineVersionCommand extends $Command<DeleteCustomDBEngineVersionCommandInput, DeleteCustomDBEngineVersionCommandOutput, RDSClientResolvedConfig> {
    readonly input: DeleteCustomDBEngineVersionCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: DeleteCustomDBEngineVersionCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: RDSClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DeleteCustomDBEngineVersionCommandInput, DeleteCustomDBEngineVersionCommandOutput>;
    private serialize;
    private deserialize;
}
