import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { SwitchoverReadReplicaMessage, SwitchoverReadReplicaResult } from "../models/models_1";
import { RDSClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../RDSClient";
export interface SwitchoverReadReplicaCommandInput extends SwitchoverReadReplicaMessage {
}
export interface SwitchoverReadReplicaCommandOutput extends SwitchoverReadReplicaResult, __MetadataBearer {
}
/**
 * <p>Switches over an Oracle standby database in an Oracle Data Guard environment, making it the new
 *             primary database. Issue this command in the Region that hosts the current standby database.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { RDSClient, SwitchoverReadReplicaCommand } from "@aws-sdk/client-rds"; // ES Modules import
 * // const { RDSClient, SwitchoverReadReplicaCommand } = require("@aws-sdk/client-rds"); // CommonJS import
 * const client = new RDSClient(config);
 * const command = new SwitchoverReadReplicaCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link SwitchoverReadReplicaCommandInput} for command's `input` shape.
 * @see {@link SwitchoverReadReplicaCommandOutput} for command's `response` shape.
 * @see {@link RDSClientResolvedConfig | config} for RDSClient's `config` shape.
 *
 */
export declare class SwitchoverReadReplicaCommand extends $Command<SwitchoverReadReplicaCommandInput, SwitchoverReadReplicaCommandOutput, RDSClientResolvedConfig> {
    readonly input: SwitchoverReadReplicaCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: SwitchoverReadReplicaCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: RDSClientResolvedConfig, options?: __HttpHandlerOptions): Handler<SwitchoverReadReplicaCommandInput, SwitchoverReadReplicaCommandOutput>;
    private serialize;
    private deserialize;
}
